==> isis-fish-3.3.0.5-sources.jar: fr/ifremer/isisfish/entities/TripTypeAbstract.java <==
package fr.ifremer.isisfish.entities;

import fr.ifremer.isisfish.types.TimeUnit;
import java.io.Serializable;
import java.util.ArrayList;
import java.util.List;
import org.apache.commons.lang.builder.ToStringBuilder;
import org.nuiton.topia.TopiaException;
import org.nuiton.topia.framework.TopiaContextImplementor;
import org.nuiton.topia.persistence.EntityVisitor;
import org.nuiton.topia.persistence.TopiaEntity;
import org.nuiton.topia.persistence.TopiaEntityAbstract;


public abstract class TripTypeAbstract extends TopiaEntityAbstract implements TripType {

    private String name;
    private TimeUnit tripDuration;
    private TimeUnit minTimeBetweenTrip;
    private String comment;
    /**
     * update :
     * @throws TopiaException
     */

    public void update() throws TopiaException {
        ((TopiaContextImplementor)getTopiaContext()).getDAO(TripType.class).update(this);
}

    /**
     * delete :
     * @throws TopiaException
     */

    public void delete() throws TopiaException {
        ((TopiaContextImplementor)getTopiaContext()).getDAO(TripType.class).delete(this);
}

    /**
     * accept :
     * Envoi via les methodes du visitor l'ensemble des champs de l'entity
avec leur nom, type et valeur.
     * @param visitor le visiteur de l'entite.
     * @throws TopiaException
     */

    public void accept(EntityVisitor visitor) throws TopiaException {
        visitor.start(this);
        visitor.visit(this, "name", String.class, name);
        visitor.visit(this, "tripDuration", TimeUnit.class, tripDuration);
        visitor.visit(this, "minTimeBetweenTrip", TimeUnit.class, minTimeBetweenTrip);
        visitor.visit(this, "comment", String.class, comment);
        visitor.end(this);
}

    /**
     * accept :
     * @return List<TopiaEntity> 
     * @throws TopiaException
     */

    public List<TopiaEntity> accept() throws TopiaException {
        List<TopiaEntity> tmp = new ArrayList<TopiaEntity>();

        // pour tous les attributs rechecher les composites et les class d'asso
        // on les ajoute dans tmp

        // on refait un tour sur chaque entity de tmp pour recuperer leur
        // composite
        List<TopiaEntity> result = new ArrayList<TopiaEntity>();
        for (TopiaEntity entity : tmp) {
            result.add(entity);
            result.addAll(entity.getAggregate());
        }

        return result;
}

    /**
     * getComposite :
     * @return List<TopiaEntity> 
     * @throws TopiaException
     */

    public List<TopiaEntity> getComposite() throws TopiaException {
        List<TopiaEntity> tmp = new ArrayList<TopiaEntity>();

        // pour tous les attributs rechecher les composites et les class d'asso
        // on les ajoute dans tmp

        // on refait un tour sur chaque entity de tmp pour recuperer leur
        // composite
        List<TopiaEntity> result = new ArrayList<TopiaEntity>();
        for (TopiaEntity entity : tmp) {
            if (entity != null) {
                result.add(entity);
                result.addAll(entity.getComposite());
            }
        }

        return result;
}

    /**
     * setName :
     * @param value 
     */

    public void setName(String value) {
        String _oldValue = this.name;
        fireOnPreWrite("name", _oldValue, value);
        this.name = value;
        fireOnPostWrite("name", _oldValue, value);
}

    /**
     * getName :
     * @return String 
     */

    public String getName() {
        fireOnPreRead("name", name);
        String result = this.name;
        fireOnPostRead("name", name);
        return result;
}

    /**
     * setTripDuration :
     * @param value 
     */

    public void setTripDuration(TimeUnit value) {
        TimeUnit _oldValue = this.tripDuration;
        fireOnPreWrite("tripDuration", _oldValue, value);
        this.tripDuration = value;
        fireOnPostWrite("tripDuration", _oldValue, value);
}

    /**
     * getTripDuration :
     * @return TimeUnit 
     */

    public TimeUnit getTripDuration() {
        fireOnPreRead("tripDuration", tripDuration);
        TimeUnit result = this.tripDuration;
        fireOnPostRead("tripDuration", tripDuration);
        return result;
}

    /**
     * setMinTimeBetweenTrip :
     * @param value 
     */

    public void setMinTimeBetweenTrip(TimeUnit value) {
        TimeUnit _oldValue = this.minTimeBetweenTrip;
        fireOnPreWrite("minTimeBetweenTrip", _oldValue, value);
        this.minTimeBetweenTrip = value;
        fireOnPostWrite("minTimeBetweenTrip", _oldValue, value);
}

    /**
     * getMinTimeBetweenTrip :
     * @return TimeUnit 
     */

    public TimeUnit getMinTimeBetweenTrip() {
        fireOnPreRead("minTimeBetweenTrip", minTimeBetweenTrip);
        TimeUnit result = this.minTimeBetweenTrip;
        fireOnPostRead("minTimeBetweenTrip", minTimeBetweenTrip);
        return result;
}

    /**
     * setComment :
     * @param value 
     */

    public void setComment(String value) {
        String _oldValue = this.comment;
        fireOnPreWrite("comment", _oldValue, value);
        this.comment = value;
        fireOnPostWrite("comment", _oldValue, value);
}

    /**
     * getComment :
     * @return String 
     */

    public String getComment() {
        fireOnPreRead("comment", comment);
        String result = this.comment;
        fireOnPostRead("comment", comment);
        return result;
}

    /**
     * toString :
     * @return String 
     */

    @Override
    public String toString() {
        String result = new ToStringBuilder(this).
            append("name", this.name).
            append("tripDuration", this.tripDuration).
            append("minTimeBetweenTrip", this.minTimeBetweenTrip).
            append("comment", this.comment).
         toString();
        return result;
}


} //TripTypeAbstract

==> isis-fish-3.3.0.6-sources.jar: fr/ifremer/isisfish/entities/TripTypeAbstract.java <==
/*
 * #%L
 * IsisFish
 * 
 * $Id$
 * $HeadURL$
 * %%
 * Copyright (C) 1999 - 2010 CodeLutin
 * %%
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as
 * published by the Free Software Foundation, either version 2 of the 
 * License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public 
 * License along with this program.  If not, see
 * <http://www.gnu.org/licenses/gpl-2.0.html>.
 * #L%
 */
package fr.ifremer.isisfish.entities;

import fr.ifremer.isisfish.types.TimeUnit;
import java.util.ArrayList;
import java.util.List;
import org.apache.commons.lang.builder.ToStringBuilder;
import org.nuiton.topia.TopiaException;
import org.nuiton.topia.framework.TopiaContextImplementor;
import org.nuiton.topia.persistence.EntityVisitor;
import org.nuiton.topia.persistence.TopiaEntity;
import org.nuiton.topia.persistence.TopiaEntityAbstract;


public abstract class TripTypeAbstract extends TopiaEntityAbstract implements TripType {

    protected String name;
    protected TimeUnit tripDuration;
    protected TimeUnit minTimeBetweenTrip;
    protected String comment;
    /**
     * update :
     * @throws TopiaException
     */

    public void update() throws TopiaException {
        ((TopiaContextImplementor)getTopiaContext()).getDAO(TripType.class).update(this);
}

    /**
     * delete :
     * @throws TopiaException
     */

    public void delete() throws TopiaException {
        ((TopiaContextImplementor)getTopiaContext()).getDAO(TripType.class).delete(this);
}

    /**
     * accept :
     * Envoi via les methodes du visitor l'ensemble des champs de l'entity
avec leur nom, type et valeur.
     * @param visitor le visiteur de l'entite.
     * @throws TopiaException
     */

    public void accept(EntityVisitor visitor) throws TopiaException {
        visitor.start(this);
        visitor.visit(this, NAME, String.class, name);
        visitor.visit(this, TRIP_DURATION, TimeUnit.class, tripDuration);
        visitor.visit(this, MIN_TIME_BETWEEN_TRIP, TimeUnit.class, minTimeBetweenTrip);
        visitor.visit(this, COMMENT, String.class, comment);
        visitor.end(this);
}

    /**
     * accept :
     * @return List<TopiaEntity> 
     * @throws TopiaException
     */

    public List<TopiaEntity> accept() throws TopiaException {
        List<TopiaEntity> tmp = new ArrayList<TopiaEntity>();

        // pour tous les attributs rechecher les composites et les class d'asso
        // on les ajoute dans tmp

        // on refait un tour sur chaque entity de tmp pour recuperer leur
        // composite
        List<TopiaEntity> result = new ArrayList<TopiaEntity>();
        for (TopiaEntity entity : tmp) {
            result.add(entity);
            result.addAll(entity.getAggregate());
        }

        return result;
}

    /**
     * getComposite :
     * @return List<TopiaEntity> 
     * @throws TopiaException
     */

    public List<TopiaEntity> getComposite() throws TopiaException {
        List<TopiaEntity> tmp = new ArrayList<TopiaEntity>();

        // pour tous les attributs rechecher les composites et les class d'asso
        // on les ajoute dans tmp

        // on refait un tour sur chaque entity de tmp pour recuperer leur
        // composite
        List<TopiaEntity> result = new ArrayList<TopiaEntity>();
        for (TopiaEntity entity : tmp) {
            if (entity != null) {
                result.add(entity);
                result.addAll(entity.getComposite());
            }
        }

        return result;
}

    /**
     * setName :
     * @param value 
     */

    public void setName(String value) {
        String _oldValue = this.name;
        fireOnPreWrite(NAME, _oldValue, value);
        this.name = value;
        fireOnPostWrite(NAME, _oldValue, value);
}

    /**
     * getName :
     * @return String 
     */

    public String getName() {
        fireOnPreRead(NAME, name);
        String result = this.name;
        fireOnPostRead(NAME, name);
        return result;
}

    /**
     * setTripDuration :
     * @param value 
     */

    public void setTripDuration(TimeUnit value) {
        TimeUnit _oldValue = this.tripDuration;
        fireOnPreWrite(TRIP_DURATION, _oldValue, value);
        this.tripDuration = value;
        fireOnPostWrite(TRIP_DURATION, _oldValue, value);
}

    /**
     * getTripDuration :
     * @return TimeUnit 
     */

    public TimeUnit getTripDuration() {
        fireOnPreRead(TRIP_DURATION, tripDuration);
        TimeUnit result = this.tripDuration;
        fireOnPostRead(TRIP_DURATION, tripDuration);
        return result;
}

    /**
     * setMinTimeBetweenTrip :
     * @param value 
     */

    public void setMinTimeBetweenTrip(TimeUnit value) {
        TimeUnit _oldValue = this.minTimeBetweenTrip;
        fireOnPreWrite(MIN_TIME_BETWEEN_TRIP, _oldValue, value);
        this.minTimeBetweenTrip = value;
        fireOnPostWrite(MIN_TIME_BETWEEN_TRIP, _oldValue, value);
}

    /**
     * getMinTimeBetweenTrip :
     * @return TimeUnit 
     */

    public TimeUnit getMinTimeBetweenTrip() {
        fireOnPreRead(MIN_TIME_BETWEEN_TRIP, minTimeBetweenTrip);
        TimeUnit result = this.minTimeBetweenTrip;
        fireOnPostRead(MIN_TIME_BETWEEN_TRIP, minTimeBetweenTrip);
        return result;
}

    /**
     * setComment :
     * @param value 
     */

    public void setComment(String value) {
        String _oldValue = this.comment;
        fireOnPreWrite(COMMENT, _oldValue, value);
        this.comment = value;
        fireOnPostWrite(COMMENT, _oldValue, value);
}

    /**
     * getComment :
     * @return String 
     */

    public String getComment() {
        fireOnPreRead(COMMENT, comment);
        String result = this.comment;
        fireOnPostRead(COMMENT, comment);
        return result;
}

    /**
     * toString :
     * @return String 
     */

    @Override
    public String toString() {
        String result = new ToStringBuilder(this).
            append(NAME, this.name).
            append(TRIP_DURATION, this.tripDuration).
            append(MIN_TIME_BETWEEN_TRIP, this.minTimeBetweenTrip).
            append(COMMENT, this.comment).
         toString();
        return result;
}


} //TripTypeAbstract
